@@ -30,6 +30,7 @@ from datalad.utils import (
     rmtree
 )
 from datalad.support.exceptions import IncompleteResultsError
+from datalad.support.external_versions import external_versions
 from datalad.support.gitrepo import GitRepo
 from datalad.support.annexrepo import AnnexRepo
 from datalad.cmd import (
@@ -56,6 +57,7 @@ from datalad.tests.utils import (
     integration,
     known_failure,
     known_failure_githubci_win,
+    known_failure_osx,
     known_failure_windows,
     neq_,
     nok_,
@@ -1157,6 +1159,7 @@ def _postclonetest_prepare(lcl, storepath, storepath2, link):
     return ds.id
 
 
+@known_failure_osx  # https://github.com/datalad/datalad/issues/6599
 @known_failure_windows  # https://github.com/datalad/datalad/issues/5134
 @slow  # 14 sec on travis
 def test_ria_postclonecfg():
@@ -1372,6 +1375,7 @@ def test_ephemeral(origin_path, bare_path,
     origin.save()
     # 1. clone via path
     clone1 = clone(origin_path, clone1_path, reckless='ephemeral')
+    eq_(clone1.config.get("annex.private"), "true")
 
     can_symlink = has_symlink_capability()
 
@@ -1387,6 +1391,7 @@ def test_ephemeral(origin_path, bare_path,
     # 2. clone via file-scheme URL
     clone2 = clone('file://' + Path(origin_path).as_posix(), clone2_path,
                    reckless='ephemeral')
+    eq_(clone2.config.get("annex.private"), "true")
 
     if can_symlink:
         clone2_annex = (clone2.repo.dot_git / 'annex')
@@ -1406,8 +1411,16 @@ def test_ephemeral(origin_path, bare_path,
                       scope="local")
     # Note, that the only thing to test is git-annex-dead here,
     # if we couldn't symlink:
-    clone1.push(to=DEFAULT_REMOTE,
-                   data='nothing' if can_symlink else 'auto')
+    clone1.push(to=DEFAULT_REMOTE, data='nothing' if can_symlink else 'auto')
+
+    if external_versions['cmd:annex'] >= "8.20210428":
+        # ephemeral clones are private (if supported by annex version). Despite
+        # the push, clone1's UUID doesn't show up in origin
+        recorded_locations = origin.repo.call_git(['cat-file', 'blob',
+                                                   'git-annex:uuid.log'],
+                                                  read_only=True)
+        assert_not_in(clone1.config.get("annex.uuid"), recorded_locations)
+
     if not origin.repo.is_managed_branch():
         # test logic cannot handle adjusted branches
         eq_(origin.repo.get_hexsha(), clone1.repo.get_hexsha())
