@@ -1,5 +1,5 @@
 # emacs: -*- mode: python-mode; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil; coding: utf-8 -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -8,22 +8,26 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Test EXIF extractor"""
 
-from datalad.tests.utils import SkipTest
+from datalad.tests.utils import (
+    assert_in,
+    assert_repo_status,
+    assert_result_count,
+    assert_status,
+    eq_,
+    SkipTest,
+    with_tempfile,
+)
 try:
     import exifread
 except ImportError:
     raise SkipTest
 
 from shutil import copy
-from os.path import dirname
-from os.path import join as opj
+from os.path import (
+    dirname,
+    join as opj,
+)
 from datalad.api import Dataset
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import ok_clean_git
-from datalad.tests.utils import assert_status
-from datalad.tests.utils import assert_result_count
-from datalad.tests.utils import eq_
-from datalad.tests.utils import assert_in
 
 
 target = {
@@ -77,12 +81,12 @@ target = {
 @with_tempfile(mkdir=True)
 def test_exif(path):
     ds = Dataset(path).create()
-    ds.config.add('datalad.metadata.nativetype', 'exif', where='dataset')
+    ds.config.add('datalad.metadata.nativetype', 'exif', scope='branch')
     copy(
         opj(dirname(dirname(dirname(__file__))), 'tests', 'data', 'exif.jpg'),
         path)
     ds.save()
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     res = ds.aggregate_metadata()
     assert_status('ok', res)
     res = ds.metadata('exif.jpg')
