@@ -1,5 +1,5 @@
 #emacs: -*- mode: python-mode; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*- 
-#ex: set sts=4 ts=4 sw=4 noet:
+#ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -36,7 +36,6 @@ from datalad.tests.utils import (
     ok_exists,
     on_osx,
     with_tempfile,
-    known_failure_windows,
 )
 
 
@@ -55,7 +54,6 @@ class Subproc:
             q.put(acquired)
 
 
-@known_failure_windows
 @with_tempfile
 def test_lock_if_check_fails(tempfile):
     # basic test, should never try to lock so filename is not important
