@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -389,6 +389,6 @@ class AnnexSpecialRemoteProgressBar(ProgressBarBase):
         super(AnnexSpecialRemoteProgressBar, self).update(*args, **kwargs)
         # now use stored value
         if self.remote:
-            self.remote.progress(self.current)
+            self.remote.send_progress(self.current)
 
 progressbars['annex-remote'] = AnnexSpecialRemoteProgressBar
